translate.lang.pa

Package translate :: Package lang :: Module pa |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.pa

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2010 Zuza Software Foundation
     5  #
     6  # This file is part of the Translate Toolkit.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """This module represents Punjabi language.
    22
    23  For more information, see U{http://en.wikipedia.org/wiki/Punjabi_language}
    24  """
    25
    26  import re
    27
    28  from translate.lang import common
    29
    30 -class pa(common.Common):
    31      """This class represents Punjabi."""
    32
    33      sentenceend = u"।!?…"
    34
    35      sentencere = re.compile(r"""(?s)    #make . also match newlines
    36                              .*?         #anything, but match non-greedy
    37                              [%s]        #the puntuation for sentence ending
    38                              \s+         #the spacing after the puntuation
    39                              (?=[^a-z\d])#lookahead that next part starts with caps
    40                              """ % sentenceend, re.VERBOSE)
    41
    42      puncdict = {
    43          u". ": u"। ",
    44          u".\n": u"।\n",
    45      }
    46
    47      ignoretests = ["startcaps", "simplecaps"]
    48